@@ -121,7 +121,7 @@ pilot_connect (GPilotDevice *device,int *error)
 	struct pi_sockaddr addr;
 	int sd, listen_sd, pf;
 	int ret;
-	
+    
 	if (device->type != PILOT_DEVICE_NETWORK) {
 		pilot_set_baud_rate (device);
 	}
@@ -191,7 +191,7 @@ pilot_connect (GPilotDevice *device,int *error)
 		pi_close(listen_sd);
 		return 0;
 	}
-		
+
 	if (error)
 		*error = 0;
 	pi_close(listen_sd);
@@ -626,11 +626,12 @@ static gboolean
 sync_device (GPilotDevice *device, GPilotContext *context)
 {
 	GPilotPilot *pilot;
+	
 	int pfd;
 	int connect_error;
 	struct PilotUser pu;
 	struct SysInfo ps;
-	
+
 	g_assert (context != NULL);
 	g_return_val_if_fail (device != NULL, FALSE);
 
@@ -638,16 +639,15 @@ sync_device (GPilotDevice *device, GPilotContext *context)
 	pfd = pilot_connect (device,&connect_error);
 
 	if (!connect_error) {
-		/* connect succeeded, try to read the systeminfo */
-		if (dlp_ReadSysInfo (pfd, &ps) < 0) {
-			/* no ? drop connection then */
-			g_warning (_("An error occured while getting the pilot's system data"));
+               /* connect succeeded, try to read the systeminfo */
+               if (dlp_ReadSysInfo (pfd, &ps) < 0) {
+                       /* no ? drop connection then */
+                       g_warning (_("An error occured while getting the pilot's system data"));
 
 		/* connect succeeded, try to read the userinfo */
 		} else if (dlp_ReadUserInfo (pfd,&pu) < 0) {
 			/* no ? drop connection then */
 			g_warning (_("An error occured while getting the pilot's user data"));
-
 		} else {
 	
 			/* If there are cradle specific events, handle them and stop */
@@ -847,13 +847,12 @@ static const char *product_names[] =
 
 static gboolean product_net[] =
 {
-	FALSE,
-	TRUE,
-	TRUE,
-	-1
+       FALSE,
+       TRUE,
+       TRUE,
+       -1
 };
 
-
 static gboolean 
 visor_devices_in (GIOChannel *io_channel,
 		 GIOCondition condition,
@@ -900,7 +899,7 @@ visor_devices_in (GIOChannel *io_channel,
 			if (device->type == PILOT_DEVICE_USB_VISOR) {
 				if (!visor_net)
 					device->type = PILOT_DEVICE_SERIAL;
-				
+
 				/* just try to synch.  Until I can talk to 
 				 * the kernel guys this is the best way to 
                                  * go. */
@@ -1024,7 +1023,7 @@ sig_int_handler (int dummy) {
 /* This deletes the ~/.gpilotd.pid file */
 void 
 remove_pid_file () {
-	gchar *home_directory;
+	const gchar *home_directory;
 	gchar *pid_file;
 
 	home_directory=g_get_home_dir ();
@@ -1078,7 +1077,7 @@ write_pid_file ()
 	} else {
 		g_warning (_("Unable to find home directory for uid %d"),geteuid ());
 	}
-	if (g_file_test (queue_dir, G_FILE_TEST_ISDIR)==FALSE) {
+	if (g_file_test (queue_dir, G_FILE_TEST_IS_DIR)==FALSE) {
 		if (mkdir (queue_dir, 0700)) {
 			g_warning (_("Unable to create file installation queue directory"));
 		}
@@ -1159,13 +1158,14 @@ main (int argc, char *argv[])
 	g_message ("%s %s starting...",PACKAGE,VERSION);
 	dump_build_info ();
 
-
+	gnome_init (PACKAGE, VERSION, argc, argv);
+	
 	/* Setup the correct gpilotd.pid file */
 	remove_pid_file ();
 	write_pid_file ();
 
 	/* Init corba and context, this call also loads the config into context */
-	gtk_type_init ();
+	g_type_init ();
 	gpilotd_corba_init (&argc,argv,&context);
 
 	reread_config=FALSE;	
