@@ -228,17 +228,12 @@ set_callbacks (gboolean set, GnomePilotConduit *conduit, gchar *pilot_name)
 		if (progress_h != 0) g_warning ("Internal inconsistency, see %s:%d",
 					       __FILE__,__LINE__);
 		
-		progress_h = gtk_signal_connect (GTK_OBJECT (conduit),
-						 GNOME_PILOT_CONDUIT_SIGNAL_PROGRESS (conduit_progress_callback),
-						 pilot_name);
-		
-		error_h = gtk_signal_connect (GTK_OBJECT (conduit),
-					      GNOME_PILOT_CONDUIT_SIGNAL_ERROR (conduit_error_callback),
-					      pilot_name);
-		
-		message_h = gtk_signal_connect (GTK_OBJECT (conduit),
-					       GNOME_PILOT_CONDUIT_SIGNAL_MESSAGE (conduit_message_callback),
-					       pilot_name);	       
+		progress_h = gnome_pilot_conduit_connect__progress (conduit, conduit_progress_callback,
+								    pilot_name);
+		error_h = gnome_pilot_conduit_connect__error  (conduit, conduit_error_callback,
+							       pilot_name);
+		message_h = gnome_pilot_conduit_connect__message (conduit, conduit_message_callback,
+								  pilot_name);
 	} else {
 		if (progress_h == 0) {
 			/* We should never have set==FALSE but no progress_h(andler)
@@ -684,7 +679,7 @@ gpilot_load_conduits (GPilotContext *context,
 		}
 		
 		gtk_object_set (GTK_OBJECT (conduit),
-				GNOME_PILOT_CONDUIT_ARG_PROGRESS_STEPPING (context->progress_stepping),
+				GNOME_PILOT_CONDUIT_PROP_PROGRESS_STEPPING (context->progress_stepping),
 				NULL);
 		gtk_object_set_data (GTK_OBJECT (conduit), GPCM_LABEL, manager);
 		gtk_object_set_data (GTK_OBJECT (conduit), GPCC_LABEL, conduit_config);
